%define  bootstrap  0

# Allow --with[out] bootstrap at rpm command line build
%{?_without_bootstrap: %{expand: %%define bootstrap 0}}
%{?_with_bootstrap: %{expand: %%define bootstrap 1}}

Name:    xinit
Version: 1.3.4
Release: %mkrel 4
Summary: Initialize an X session
License: MIT
Group:   System/X11
URL:        http://www.x.org

Source0: http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.bz2

# Fedora specific patches
# (fc) prevent freeze from applications trying to read stdin (Fedora bug #214649)
Patch1: xinit-1.0.2-client-session.patch
# A few fixes submitted upstream, rhbz#1177513, rhbz#1203780
Patch3: 0001-startx-Pass-keeptty-when-telling-the-server-to-start.patch
Patch4: 0002-startx-Fix-startx-picking-an-already-used-display-nu.patch
Patch5: 0003-startx-Make-startx-auto-display-select-work-with-per.patch

# Mageia patches:

# (fc) 1.0.2-2mdv read modifications for startx (argument parsing)
# This patch is part of the old "startx" patch.
# We need to check why exactly this patch is needed, but it does these things:
# - it removes the default client and server from the startx arguments, so if
#   nothing is specified the default server or client will be the one chosen by
#   xinit
# - it uses trap to make sure the "cleanup" function will be run
# - it partially undoes upstream commit 9632367abd03108f3636b05e9f2fd92f5c28dabe
# - it enables commands like "startx startxfce4", which don't work in the
#   unpatched version (should be "startx /usr/bin/startxfce4")
#Previous versions of this patch had a bug where xinit would be run twice if some
#macros were defined.
Patch50: xinit-1.3.4-startx-arguments.patch

# (fc) unset XDG_SESSION_COOKIE in startx (Fedora bug #489999)
Patch53: xinit-1.0.9-unset.patch

# (pz) this patch was taken from the old startx.patch
Patch54: xinit-1.3.4-replace-xterm-for-xvt.patch

# (cg) use the current vt to maintain the current session status.
Patch55: xinit-1.3.2-use-current-vt.patch

BuildRequires: libx11-devel >= 1.0.0
BuildRequires: x11-util-macros >= 1.0.1
Requires:      xinitrc

%if !%{bootstrap}
Requires:      which
%endif


%description
The xinit program is used to start the X Window System server and a first
client program on systems that cannot start X directly from /etc/init or in
environments that use multiple window systems. When this first client exits,
xinit will kill the X server and then terminate.


%prep
%setup -q
%patch1 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

# Mga patches:
%patch50 -p1 -b .orig

%patch53 -p1 -b .unset
%patch54 -p1 -b .xvt


%build
autoreconf
%configure2_5x
%make XINITDIR=/etc/X11/xinit

%install
%makeinstall_std

#don't use xorg xinitrc file, use our own, provided by xinitrc package
rm -fr %buildroot{%{_libdir},%{_sysconfdir}}/X11/xinit/xinitrc

%files
%{_bindir}/xinit
%{_bindir}/startx
%if !%{bootstrap}
%endif
%{_mandir}/man1/startx.1*
%{_mandir}/man1/xinit.1*




%changelog
* Thu Apr 21 2016 tv <tv> 1.3.4-4.mga6
+ Revision: 1004067
- add few FC fixes submitted upstream (rhbz#1177513, rhbz#1203780)
  o Pass -keeptty when telling the server to start on the current tty
  o Fix startx picking an already used display number when -nolock is used
  o Make startx auto display select work with per user /tmp dirs
- renumber mga patches
- replace patch 2 patch FC version

* Fri Feb 05 2016 umeabot <umeabot> 1.3.4-3.mga6
+ Revision: 939715
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.3.4-2.mga5
+ Revision: 744498
- Second Mageia 5 Mass Rebuild

* Fri Oct 10 2014 eatdirt <eatdirt> 1.3.4-1.mga5
+ Revision: 737809
- Upgrade to version 1.3.4 (fix starting vt)

* Tue Sep 16 2014 umeabot <umeabot> 1.3.3-4.mga5
+ Revision: 690668
- Mageia 5 Mass Rebuild

* Fri Jan 03 2014 eatdirt <eatdirt> 1.3.3-3.mga4
+ Revision: 564052
- Fix empty lines before #!/bin/sh (bug #12169)

* Sat Oct 19 2013 umeabot <umeabot> 1.3.3-2.mga4
+ Revision: 534484
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 tv <tv> 1.3.3-1.mga4
+ Revision: 477987
- fix build
- new release

* Mon Jan 14 2013 umeabot <umeabot> 1.3.2-5.mga3
+ Revision: 387057
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 19 2012 ovitters <ovitters> 1.3.2-4.mga3
+ Revision: 308235
- drop consolekit support (+1'ed by coling)
- clean spec

* Fri Apr 06 2012 colin <colin> 1.3.2-3.mga2
+ Revision: 229253
- Nicer way to get current tty

* Fri Apr 06 2012 colin <colin> 1.3.2-2.mga2
+ Revision: 229209
- Attempt to detect and reuse the current vt (to preserve login session 'active' status and thus permissions)

* Sat Feb 25 2012 eatdirt <eatdirt> 1.3.2-1.mga2
+ Revision: 214628
- Upgrade to 1.3.2, startx patch fixed

  + tv <tv>
    - new release

* Fri Jan 21 2011 ennael <ennael> 1.3.0-1.mga1
+ Revision: 27603
- imported package xinit

